---
title: corgy.types
---
::: corgy.types
    options:
      show_root_heading: false
      show_root_toc_entry: false
::: corgy.types.KeyValuePairs
::: corgy.types.SubClass
::: corgy.types.InitArgs
::: corgy.types.InputTextFile
::: corgy.types.InputBinFile
::: corgy.types.OutputTextFile
::: corgy.types.LazyOutputTextFile
::: corgy.types.OutputBinFile
::: corgy.types.LazyOutputBinFile
